==> vala-0.1.0.tar.bz2: vala-0.1.0/ccode/valaccodecomment.c <==
/* valaccodecomment.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */
#define VALA_FREE_CHECKED(o,f) ((o) == NULL ? NULL : ((o) = (f (o), NULL)))
#define VALA_FREE_UNCHECKED(o,f) ((o) = (f (o), NULL))

#include "valaccodecomment.h"
#include <ccode/valaccodecomment.h>

struct _ValaCCodeCommentPrivate {
	char* _text;
};
#define VALA_CCODE_COMMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_COMMENT, ValaCCodeCommentPrivate))
enum  {
	VALA_CCODE_COMMENT_DUMMY_PROPERTY,
	VALA_CCODE_COMMENT_TEXT
};
static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_comment_parent_class = NULL;
static void vala_ccode_comment_dispose (GObject * obj);


ValaCCodeComment* vala_ccode_comment_new (const char* _text)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeComment * self;
	g_return_val_if_fail (_text != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "text", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _text), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_COMMENT, __params_it - __params, __params);
	return self;
}


static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeComment * self;
	self = VALA_CCODE_COMMENT (base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_comment (writer, vala_ccode_comment_get_text (self));
}


char* vala_ccode_comment_get_text (ValaCCodeComment* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_COMMENT (self), NULL);
	return self->priv->_text;
}


void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value)
{
	char* __temp1;
	g_return_if_fail (VALA_IS_CCODE_COMMENT (self));
	__temp1 = NULL;
	self->priv->_text = (__temp1 = g_strdup (value), (self->priv->_text = (g_free (self->priv->_text), NULL)), __temp1);
}


static void vala_ccode_comment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeComment * self;
	self = VALA_CCODE_COMMENT (object);
	switch (property_id) {
		case VALA_CCODE_COMMENT_TEXT:
		g_value_set_string (value, vala_ccode_comment_get_text (self));
		break;
	}
}


static void vala_ccode_comment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeComment * self;
	self = VALA_CCODE_COMMENT (object);
	switch (property_id) {
		case VALA_CCODE_COMMENT_TEXT:
		vala_ccode_comment_set_text (self, g_value_get_string (value));
		break;
	}
}


static void vala_ccode_comment_class_init (ValaCCodeCommentClass * klass)
{
	vala_ccode_comment_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeCommentPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_comment_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_comment_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_comment_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_comment_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_COMMENT_TEXT, g_param_spec_string ("text", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_comment_init (ValaCCodeComment * self)
{
	self->priv = VALA_CCODE_COMMENT_GET_PRIVATE (self);
}


static void vala_ccode_comment_dispose (GObject * obj)
{
	ValaCCodeComment * self;
	ValaCCodeCommentClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_COMMENT (obj);
	(self->priv->_text = (g_free (self->priv->_text), NULL));
	klass = VALA_CCODE_COMMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_COMMENT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_comment_get_type ()
{
	static GType vala_ccode_comment_type_id = 0;
	if (G_UNLIKELY (vala_ccode_comment_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeComment), 0, (GInstanceInitFunc) vala_ccode_comment_init };
		vala_ccode_comment_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeComment", &g_define_type_info, 0);
	}
	return vala_ccode_comment_type_id;
}

==> vala-0.1.2.tar.bz2: vala-0.1.2/ccode/valaccodecomment.c <==
/* valaccodecomment.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaccodecomment.h"
#include <ccode/valaccodecomment.h>

struct _ValaCCodeCommentPrivate {
	char* _text;
};
#define VALA_CCODE_COMMENT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_COMMENT, ValaCCodeCommentPrivate))
enum  {
	VALA_CCODE_COMMENT_DUMMY_PROPERTY,
	VALA_CCODE_COMMENT_TEXT
};
static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_comment_parent_class = NULL;
static void vala_ccode_comment_dispose (GObject * obj);


ValaCCodeComment* vala_ccode_comment_new (const char* _text)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeComment * self;
	g_return_val_if_fail (_text != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "text", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _text), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_COMMENT, __params_it - __params, __params);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_ccode_comment_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeComment * self;
	self = ((ValaCCodeComment*) base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_comment (writer, vala_ccode_comment_get_text (self));
}


char* vala_ccode_comment_get_text (ValaCCodeComment* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_COMMENT (self), NULL);
	return self->priv->_text;
}


void vala_ccode_comment_set_text (ValaCCodeComment* self, const char* value)
{
	char* __temp1;
	g_return_if_fail (VALA_IS_CCODE_COMMENT (self));
	__temp1 = NULL;
	self->priv->_text = (__temp1 = g_strdup (value), (self->priv->_text = (g_free (self->priv->_text), NULL)), __temp1);
}


static void vala_ccode_comment_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeComment * self;
	self = VALA_CCODE_COMMENT (object);
	switch (property_id) {
		case VALA_CCODE_COMMENT_TEXT:
		g_value_set_string (value, vala_ccode_comment_get_text (self));
		break;
	}
}


static void vala_ccode_comment_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeComment * self;
	self = VALA_CCODE_COMMENT (object);
	switch (property_id) {
		case VALA_CCODE_COMMENT_TEXT:
		vala_ccode_comment_set_text (self, g_value_get_string (value));
		break;
	}
}


static void vala_ccode_comment_class_init (ValaCCodeCommentClass * klass)
{
	vala_ccode_comment_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeCommentPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_comment_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_comment_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_comment_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_comment_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_COMMENT_TEXT, g_param_spec_string ("text", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_comment_init (ValaCCodeComment * self)
{
	self->priv = VALA_CCODE_COMMENT_GET_PRIVATE (self);
}


static void vala_ccode_comment_dispose (GObject * obj)
{
	ValaCCodeComment * self;
	ValaCCodeCommentClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_COMMENT (obj);
	(self->priv->_text = (g_free (self->priv->_text), NULL));
	klass = VALA_CCODE_COMMENT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_COMMENT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_comment_get_type (void)
{
	static GType vala_ccode_comment_type_id = 0;
	if (G_UNLIKELY (vala_ccode_comment_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeCommentClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_comment_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeComment), 0, (GInstanceInitFunc) vala_ccode_comment_init };
		vala_ccode_comment_type_id = g_type_register_static (VALA_TYPE_CCODE_NODE, "ValaCCodeComment", &g_define_type_info, 0);
	}
	return vala_ccode_comment_type_id;
}
